==> react-atom-action-button-1.3.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import cx from 'classnames';
import AtomIcon, { ATOM_ICON_COLORS, ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import ActionButton from './ActionButton';
/**
 * Base class for the component
 */

var BASE_CLASS = 'sui-AtomActionButton';
/**
 * Available colors for the Action Button
 */

var COLORS = {
  PRIMARY: 'primary',
  ACCENT: 'accent',
  NEUTRAL: 'neutral'
};
/**
 * Available modifiers for the Action Button
 */

var MODIFIERS = {
  ACTIVE_FOCUSED: 'active',
  DISABLED: 'disabled',
  LINK: 'link'
};
/**
 * Available sizes for the Action Button
 */

var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
/**
 * Available styles for the Action Button
 */

var STYLES = {
  FILLED_NEGATIVE: 'filledNegative',
  FILLED_POSITIVE: 'filledPositive',
  OUTLINE: 'outline',
  FLAT: 'flat'
};

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends({}, res, (_extends2 = {}, _extends2[key] = BASE_CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var CLASSES = createClasses([].concat(Object.values(SIZES), Object.values(STYLES), Object.values(MODIFIERS)));
var COLOR_CLASSES = createClasses([].concat(Object.values(COLORS)), 'Color');

var AtomActionButton = function AtomActionButton(props) {
  var children = props.children,
      className = props.className,
      _props$color = props.color,
      color = _props$color === void 0 ? COLORS.PRIMARY : _props$color,
      disabled = props.disabled,
      focused = props.focused,
      href = props.href,
      icon = props.icon,
      isButton = props.isButton,
      isSubmit = props.isSubmit,
      link = props.link,
      linkFactory = props.linkFactory,
      _props$size = props.size,
      size = _props$size === void 0 ? SIZES.MEDIUM : _props$size,
      _props$style = props.style,
      style = _props$style === void 0 ? STYLES.FILLED_NEGATIVE : _props$style,
      target = props.target,
      title = props.title,
      restProps = _objectWithoutPropertiesLoose(props, ["children", "className", "color", "disabled", "focused", "href", "icon", "isButton", "isSubmit", "link", "linkFactory", "size", "style", "target", "title"]);

  var classNames = cx(BASE_CLASS, COLOR_CLASSES[color], CLASSES[style], CLASSES[size], focused && CLASSES[MODIFIERS.ACTIVE_FOCUSED], disabled && CLASSES[MODIFIERS.DISABLED], link && CLASSES[MODIFIERS.LINK], className);

  var buttonProps = _extends({
    href: href,
    isButton: isButton,
    isSubmit: isSubmit,
    link: link,
    linkFactory: linkFactory,
    target: target,
    title: title
  }, restProps);

  return /*#__PURE__*/React.createElement(ActionButton, Object.assign({}, buttonProps, {
    className: classNames
  }), /*#__PURE__*/React.createElement("div", {
    className: BASE_CLASS + "-icon"
  }, /*#__PURE__*/React.createElement(AtomIcon, {
    size: ATOM_ICON_SIZES.medium,
    color: ATOM_ICON_COLORS.currentColor
  }, icon)), /*#__PURE__*/React.createElement("div", {
    className: BASE_CLASS + "-text"
  }, children));
};

AtomActionButton.displayName = 'AtomActionButton';
export default AtomActionButton;
export { COLORS as atomActionButtonColors };
export { SIZES as atomActionButtonSizes };
export { STYLES as atomActionButtonStyles };

==> react-atom-action-button-1.4.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import cx from 'classnames';
import AtomIcon, { ATOM_ICON_COLORS, ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import ActionButton from './ActionButton';
/**
 * Base class for the component
 */

var BASE_CLASS = 'sui-AtomActionButton';
/**
 * Available colors for the Action Button
 */

var COLORS = {
  PRIMARY: 'primary',
  ACCENT: 'accent',
  NEUTRAL: 'neutral'
};
/**
 * Available modifiers for the Action Button
 */

var MODIFIERS = {
  ACTIVE_FOCUSED: 'active',
  DISABLED: 'disabled',
  LINK: 'link'
};
/**
 * Available sizes for the Action Button
 */

var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
/**
 * Available styles for the Action Button
 */

var STYLES = {
  FILLED_NEGATIVE: 'filledNegative',
  FILLED_POSITIVE: 'filledPositive',
  OUTLINE: 'outline',
  FLAT: 'flat'
};

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends({}, res, (_extends2 = {}, _extends2[key] = BASE_CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var CLASSES = createClasses([].concat(Object.values(SIZES), Object.values(STYLES), Object.values(MODIFIERS)));
var COLOR_CLASSES = createClasses([].concat(Object.values(COLORS)), 'Color');

var AtomActionButton = function AtomActionButton(props) {
  var children = props.children,
      className = props.className,
      _props$color = props.color,
      color = _props$color === void 0 ? COLORS.PRIMARY : _props$color,
      disabled = props.disabled,
      focused = props.focused,
      href = props.href,
      icon = props.icon,
      isButton = props.isButton,
      isSubmit = props.isSubmit,
      link = props.link,
      linkFactory = props.linkFactory,
      _props$size = props.size,
      size = _props$size === void 0 ? SIZES.MEDIUM : _props$size,
      _props$style = props.style,
      style = _props$style === void 0 ? STYLES.FILLED_NEGATIVE : _props$style,
      target = props.target,
      title = props.title,
      restProps = _objectWithoutPropertiesLoose(props, ["children", "className", "color", "disabled", "focused", "href", "icon", "isButton", "isSubmit", "link", "linkFactory", "size", "style", "target", "title"]);

  var classNames = cx(BASE_CLASS, COLOR_CLASSES[color], CLASSES[style], CLASSES[size], focused && CLASSES[MODIFIERS.ACTIVE_FOCUSED], disabled && CLASSES[MODIFIERS.DISABLED], link && CLASSES[MODIFIERS.LINK], className);

  var buttonProps = _extends({
    href: href,
    isButton: isButton,
    isSubmit: isSubmit,
    link: link,
    linkFactory: linkFactory,
    target: target,
    title: title
  }, restProps);

  return /*#__PURE__*/_jsxs(ActionButton, _extends({}, buttonProps, {
    className: classNames,
    children: [/*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-icon",
      children: /*#__PURE__*/_jsx(AtomIcon, {
        size: ATOM_ICON_SIZES.medium,
        color: ATOM_ICON_COLORS.currentColor,
        children: icon
      })
    }), /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-text",
      children: children
    })]
  }));
};

AtomActionButton.displayName = 'AtomActionButton';
export default AtomActionButton;
export { COLORS as atomActionButtonColors };
export { SIZES as atomActionButtonSizes };
export { STYLES as atomActionButtonStyles };
